@@ -89,13 +89,13 @@ int CG(const Geometry & geom, const SparseMatrix & A, CGData & data, const doubl
   if (print_freq<1)  print_freq=1;
 #endif
   // p is of length ncols, copy x to p for sparse MV operation
-  ComputeWAXPBY(nrow, 1.0, x, 0.0, x, p);
+  ComputeWAXPBY(nrow, 1.0, x, 0.0, x, p, A.isWaxpbyOptimized);
 #ifndef HPCG_NOMPI
   TICK(); ExchangeHalo(A,p); TOCK(t6);
 #endif
   ComputeSPMV(A, p, Ap);
-  ComputeWAXPBY(nrow, 1.0, b, -1.0, Ap, r); // r = b - Ax (x stored in p)
-  ComputeDotProduct(nrow, r, r, &normr, t4);
+  ComputeWAXPBY(nrow, 1.0, b, -1.0, Ap, r, A.isWaxpbyOptimized); // r = b - Ax (x stored in p)
+  ComputeDotProduct(nrow, r, r, &normr, t4, A.isDotProductOptimized);
   normr = sqrt(normr);
 #ifdef HPCG_DEBUG
   if (geom.rank==0) HPCG_fout << "Initial Residual = "<< normr << endl;
@@ -111,28 +111,28 @@ int CG(const Geometry & geom, const SparseMatrix & A, CGData & data, const doubl
     if (doPreconditioning)
       ComputeSYMGS(A, r, z); // Apply preconditioner
     else
-      ComputeWAXPBY(nrow, 1.0, r, 0.0, r, z); // copy r to z (no preconditioning)
+      ComputeWAXPBY(nrow, 1.0, r, 0.0, r, z, A.isWaxpbyOptimized); // copy r to z (no preconditioning)
     TOCK(t5); // Preconditioner apply time
 
     if (k == 1) {
-      TICK(); ComputeWAXPBY(nrow, 1.0, z, 0.0, z, p); TOCK(t2); // Copy Mr to p
-      TICK(); ComputeDotProduct (nrow, r, z, &rtz, t4); TOCK(t1); // rtz = r'*z
+      TICK(); ComputeWAXPBY(nrow, 1.0, z, 0.0, z, p, A.isWaxpbyOptimized); TOCK(t2); // Copy Mr to p
+      TICK(); ComputeDotProduct (nrow, r, z, &rtz, t4, A.isDotProductOptimized); TOCK(t1); // rtz = r'*z
     } else {
       oldrtz = rtz;
-      TICK(); ComputeDotProduct (nrow, r, z, &rtz, t4); TOCK(t1); // rtz = r'*z
+      TICK(); ComputeDotProduct (nrow, r, z, &rtz, t4, A.isDotProductOptimized); TOCK(t1); // rtz = r'*z
       beta = rtz/oldrtz;
-      TICK(); ComputeWAXPBY (nrow, 1.0, z, beta, p, p);  TOCK(t2); // p = beta*p + z
+      TICK(); ComputeWAXPBY (nrow, 1.0, z, beta, p, p, A.isWaxpbyOptimized);  TOCK(t2); // p = beta*p + z
     }
 
 #ifndef HPCG_NOMPI
     TICK(); ExchangeHalo(A,p); TOCK(t6);
 #endif
     TICK(); ComputeSPMV(A, p, Ap); TOCK(t3); // Ap = A*p
-    TICK(); ComputeDotProduct(nrow, p, Ap, &pAp, t4); TOCK(t1); // alpha = p'*Ap
+    TICK(); ComputeDotProduct(nrow, p, Ap, &pAp, t4, A.isDotProductOptimized); TOCK(t1); // alpha = p'*Ap
     alpha = rtz/pAp;
-    TICK(); ComputeWAXPBY(nrow, 1.0, x, alpha, p, x);// x = x + alpha*p
-    ComputeWAXPBY(nrow, 1.0, r, -alpha, Ap, r);  TOCK(t2);// r = r - alpha*Ap
-    TICK(); ComputeDotProduct(nrow, r, r, &normr, t4); TOCK(t1);
+    TICK(); ComputeWAXPBY(nrow, 1.0, x, alpha, p, x, A.isWaxpbyOptimized);// x = x + alpha*p
+    ComputeWAXPBY(nrow, 1.0, r, -alpha, Ap, r, A.isWaxpbyOptimized);  TOCK(t2);// r = r - alpha*Ap
+    TICK(); ComputeDotProduct(nrow, r, r, &normr, t4, A.isDotProductOptimized); TOCK(t1);
     normr = sqrt(normr);
 #ifdef HPCG_DEBUG
     if (geom.rank==0 && (k%print_freq == 0 || k == max_iter))
