@@ -16,6 +16,6 @@
 #define COMPUTEDOTPRODUCT_HPP
 #include "Geometry.hpp"
 int ComputeDotProduct(const local_int_t n, const double * const x, const double * const y,
-    double * const result, double & time_allreduce);
+    double * const result, double & time_allreduce, bool & isOptimized);
 
 #endif // COMPUTEDOTPRODUCT_HPP
