@@ -39,5 +39,7 @@
 */
 int ComputeSPMV( const SparseMatrix & A, const double * const x, double * const y) {
 
+  // This line and the next two lines should be removed and your version of ComputeSPMV should be used.
+  A.isSpmvOptimized = false;
   return(ComputeSPMV_ref(A, x, y));
 }
