@@ -48,7 +48,8 @@
 */
 int ComputeSYMGS( const SparseMatrix & A, const double * const x, double * const y) {
 
+  // This line and the next two lines should be removed and your version of ComputeSYMGS should be used.
+  A.isSymgsOptimized = false;
   return(ComputeSYMGS_ref(A, x, y));
 
 }
-
