@@ -78,8 +78,8 @@ void ReportResults(const Geometry & geom, const SparseMatrix & A, int numberOfCg
     double fnops_precond = fniters*3.0*fnnz; // Two GS sweeps, but only use lower triangle for first sweep
     double fnops = fnops_ddot+fnops_waxpby+fnops_sparsemv+fnops_precond;
 
-    YAML_Doc doc("HPCG-Benchmark", "1.0");
-    doc.add("HPCG Benchmark","Version 1.0 November 19, 2013");
+    YAML_Doc doc("HPCG-Benchmark", "1.1");
+    doc.add("HPCG Benchmark","Version 1.1 November 26, 2013");
 
     doc.add("Machine Summary","");
     doc.get("Machine Summary")->add("Distributed Processes",geom.size);
@@ -191,9 +191,24 @@ void ReportResults(const Geometry & geom, const SparseMatrix & A, int numberOfCg
     doc.get("Sparse Operations Overheads")->add("Halo exchange as percentage of SpMV time", (times[6])/totalSparseMVTime*100.0);
 #endif
     doc.add("********** Final Summary **********","");
-    bool isValidRun = (testcg_data->count_fail==0) && (testsymmetry_data->count_fail==0) && (testnorms_data->pass);
+    bool isValidRun = (testcg_data->count_fail==0) && (testsymmetry_data->count_fail==0) && (testnorms_data->pass) && (!global_failure);
     if (isValidRun) {
       doc.get("********** Final Summary **********")->add("HPCG result is VALID with a GFLOP/s rating of", totalGflops);
+      if (!A.isDotProductOptimized) {
+        doc.get("********** Final Summary **********")->add("Reference version of ComputeDotProduct used","Performance results are most likely suboptimal");
+      }
+      if (!A.isSpmvOptimized) {
+        doc.get("********** Final Summary **********")->add("Reference version of ComputeSPMV used","Performance results are most likely suboptimal");
+      }
+      if (!A.isSymgsOptimized) {
+        if (geom.numThreads>1)
+          doc.get("********** Final Summary **********")->add("Reference version of ComputeSYMGS used and number of threads greater than 1","Performance results are severely suboptimal");
+        else // numThreads ==1
+          doc.get("********** Final Summary **********")->add("Reference version of ComputeSYMGS used","Performance results are most likely suboptimal");
+      }
+      if (!A.isWaxpbyOptimized) {
+        doc.get("********** Final Summary **********")->add("Reference version of ComputeWAXPBY used","Performance results are most likely suboptimal");
+      }
       doc.get("********** Final Summary **********")->add("Please send the YAML file contents to","HPCG-Results@software.sandia.gov");
     } else {
       doc.get("********** Final Summary **********")->add("HPCG result is","INVALID.");
